@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 #  bln.py - a easyballoon compatible Saori module for ninix
-#  Copyright (C) 2002-2011 by Shyouzou Sugitani <shy@users.sourceforge.jp>
+#  Copyright (C) 2002-2012 by Shyouzou Sugitani <shy@users.sourceforge.jp>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -681,9 +681,9 @@ class Balloon(object):
             y_delta = int(event.y_root - self.y_root)
             if event.state & gtk.gdk.BUTTON1_MASK:
                 if self.dragmove_horizontal:
-                    self.x += x_delta * 100 / scale
+                    self.x += x_delta
                 if self.dragmove_vertical:
-                    self.y += y_delta * 100 / scale
+                    self.y += y_delta
                 self.set_position()
                 self.x_root = event.x_root
                 self.y_root = event.y_root
