@@ -3,7 +3,7 @@
 #  kawari.py - a "華和梨" compatible Shiori module for ninix
 #  Copyright (C) 2001, 2002 by Tamito KAJIYAMA
 #  Copyright (C) 2002, 2003 by MATSUMURA Namihiko <nie@counterghost.net>
-#  Copyright (C) 2002-2011 by Shyouzou Sugitani <shy@users.sourceforge.jp>
+#  Copyright (C) 2002-2012 by Shyouzou Sugitani <shy@users.sourceforge.jp>
 #  Copyright (C) 2003 by Shun-ichi TAHARA <jado@flowernet.gr.jp>
 #
 #  This program is free software; you can redistribute it and/or modify it
@@ -89,7 +89,7 @@ def create_dict(buf):
         parsed_phrases = parse_phrases(phrases)
         if parsed_phrases is None:
             logging.debug('kawari.py: syntax error at line {0:d} in {1}:'.format(*position))
-            logging.debug(phrases.strip())
+            logging.debug(phrases.strip().encode('utf-8', 'ignore'))
             continue
         if entries.startswith('['):
             add_phrases(kdict, tuple(parsed_entries), parsed_phrases)
@@ -145,7 +145,7 @@ def parse(data, start, stop_pattern=None):
             break
         elif data[i] == '"':
             i, text = parse_quotes(data, i)
-            buf.append('"{0}"'.format(text))
+            buf.append(u'"{0}"'.format(text))
         elif data[i:i + 2] == '${':
             i, text = parse_reference(data, i)
             buf.append(text)
@@ -218,7 +218,7 @@ def parse_inline_script(data, start):
         #end
         if data[i] == '"':
             i, text = parse_quotes(data, i)
-            buf.append('"{0}"'.format(text))
+            buf.append(u'"{0}"'.format(text))
         elif data[i:i + 2] == '${':
             i, text = parse_reference(data, i)
             buf.append(text)
@@ -312,7 +312,7 @@ class Kawari(object):
 
     def getstring(self, name):
         name = unicode(name, charset, 'ignore')
-        return self.get('resource.{0}'.format(name)).encode(charset, 'ignore')
+        return self.get(u'resource.{0}'.format(name)).encode(charset, 'ignore')
 
     # SHIORI/2.2 API
     def get_event_response(self, event,
@@ -342,7 +342,8 @@ class Kawari(object):
             self.system_entries['system-Sentence'] = ref[1]
             if ref[0] in self.otherghost:
                 s0, s1 = self.otherghost[ref[0]]
-                self.system_entries['system.Surface'] = ','.join((str(s0), str(s1)))
+                self.system_entries['system.Surface'] = ','.join((str(s0),
+                                                                  str(s1)))
                 self.system_entries['system-Surface'] = ','.join((str(s0),
                                                                   str(s1)))
             script = self.get_system_entry('OnResponse')
@@ -443,7 +444,7 @@ class Kawari(object):
 
     def unshift(self, name, value):
         logging.debug(
-            ('*** unshift("{0}", "{1}")'.format(name, value)).encode('utf-8',
+            (u'*** unshift("{0}", "{1}")'.format(name, value)).encode('utf-8',
                                                                      'ignore'))
         dic = self.get_internal_dict(name)
         i, segments = parse(value, 0)
@@ -453,13 +454,13 @@ class Kawari(object):
         dic = self.get_internal_dict(name)
         value = self.expand(dic[name].pop(0))
         logging.debug(
-            ('*** shift("{0}") => "{1}"'.format(name, value)).encode('utf-8',
+            (u'*** shift("{0}") => "{1}"'.format(name, value)).encode('utf-8',
                                                                      'ignore'))
         return value
 
     def push(self, name, value):
         logging.debug(
-            ('*** push("{0}", "{1}")'.format(name, value)).encode('utf-8',
+            (u'*** push("{0}", "{1}")'.format(name, value)).encode('utf-8',
                                                                   'ignore'))
         dic = self.get_internal_dict(name)
         i, segments = parse(value, 0)
@@ -469,7 +470,7 @@ class Kawari(object):
         dic = self.get_internal_dict(name)
         value = self.expand(dic[name].pop())
         logging.debug(
-            ('*** pop("{0}") => "{1}"'.format(name, value)).encode('utf-8',
+            (u'*** pop("{0}") => "{1}"'.format(name, value)).encode('utf-8',
                                                                    'ignore'))
         return value
 
@@ -1700,7 +1701,7 @@ class Shiori(Kawari):
             'Shiori: KAWARI compatible module for ninix\n'
             '        Copyright (C) 2001, 2002 by Tamito KAJIYAMA\n'
             '        Copyright (C) 2002, 2003 by MATSUMURA Namihiko\n'
-            '        Copyright (C) 2002-2011 by Shyouzou Sugitani\n'
+            '        Copyright (C) 2002-2012 by Shyouzou Sugitani\n'
             '        Copyright (C) 2003 by Shun-ichi TAHARA')
 
     def request(self, req_string):
@@ -1816,7 +1817,7 @@ class Shiori(Kawari):
               'Charset: {0}\r\n'.format(charset)
         for i in range(2, len(argv)):
             req = ''.join((req,
-                           'Argument{0}: {1}\r\n'.format(i - 2, self.expand(argv[i]))))
+                           u'Argument{0}: {1}\r\n'.format(i - 2, self.expand(argv[i]))))
         req = ''.join((req, '\r\n'))
         response = self.saori_request(self.saori_ini[alias][0],
                                       req.encode(charset, 'ignore'))
@@ -1866,7 +1867,7 @@ class Shiori(Kawari):
               'SecurityLevel: local\r\n'
         for i in range(3, len(argv)):
             req = ''.join((req,
-                           'Argument{0}: {1}\r\n'.format(i - 3, self.expand(argv[i]))))
+                           u'Argument{0}: {1}\r\n'.format(i - 3, self.expand(argv[i]))))
         req = ''.join((req, '\r\n'))
         response = self.saori_request(self.saori_ini[alias][0],
                                       req.encode(charset, 'ignore'))
