@@ -2,7 +2,7 @@
 #
 #  kawari8.py - a (Real) 華和梨 loader for ninix
 #  Copyright (C) 2002, 2003 by ABE Hideaki <abe-xx@eos.dricas.com>
-#  Copyright (C) 2002-2011 by Shyouzou Sugitani <shy@users.sourceforge.jp>
+#  Copyright (C) 2002-2012 by Shyouzou Sugitani <shy@users.sourceforge.jp>
 #  Copyright (C) 2002, 2003 by MATSUMURA Namihiko <nie@counterghost.net>
 #
 #  This program is free software; you can redistribute it and/or modify it
@@ -25,6 +25,8 @@ except:
 
 class Shiori(object):
 
+    saori_list = {}
+
     def __init__(self, dll_name):
         self.dll_name = dll_name
         self.handle = 0
@@ -42,22 +44,21 @@ class Shiori(object):
         logging.info(
             'Shiori: Real Kawari8 loader for ninix\n'
             '        Copyright (C) 2002, 2003 by ABE Hideaki\n'
-            '        Copyright (C) 2002-2011 by Shyouzou Sugitani\n'
+            '        Copyright (C) 2002-2012 by Shyouzou Sugitani\n'
             '        Copyright (C) 2002, 2003 by MATSUMURA Namihiko')
 
     def load(self, topdir):
         self.dir = topdir
-        self.saori_list = {}
         if _kawari8:
-            reload(_kawari8)
+            ##reload(_kawari8)
             if self.dir.endswith(os.sep):
                 topdir = self.dir
             else:
                 topdir = ''.join((self.dir, os.sep))
             _kawari8.setcallback(self.saori_exist,
-                                 self.saori_load,
-                                 self.saori_unload,
-                                 self.saori_request)
+                                 Shiori.saori_load,
+                                 Shiori.saori_unload,
+                                 Shiori.saori_request)
             result = _kawari8.load(topdir)
             self.handle = result
             return 1 if result != 0 else 0
@@ -67,10 +68,17 @@ class Shiori(object):
     def unload(self):
         if _kawari8:
             _kawari8.unload(self.handle)
-            for name in self.saori_list.keys():
+            for name in Shiori.saori_list.keys():
+                if not name.startswith(self.dir):
+                    continue
                 if self.saori_list[name][1]:
                     self.saori_list[name][0].unload()
                 del self.saori_list[name]
+            # XXX
+            _kawari8.setcallback(lambda *a: 0, # dummy
+                                 Shiori.saori_load,
+                                 Shiori.saori_unload,
+                                 Shiori.saori_request)
 
     def request(self, req_string):
         if _kawari8:
@@ -81,32 +89,34 @@ class Shiori(object):
     def saori_exist(self, saori):
         module = self.saori.request(saori)
         if module:
-            self.saori_list[saori] = [module, 0]
-            return len(self.saori_list)
+            Shiori.saori_list[saori] = [module, 0]
+            return len(Shiori.saori_list)
         else:
             return 0
 
-    def saori_load(self, saori, path):
+    @classmethod
+    def saori_load(cls, saori, path):
         result = 0
-        if saori in self.saori_list and self.saori_list[saori][1] == 0:
-            result = self.saori_list[saori][0].load(path)
-            self.saori_list[saori][1] = result
+        if saori in cls.saori_list and cls.saori_list[saori][1] == 0:
+            result = cls.saori_list[saori][0].load(path)
+            cls.saori_list[saori][1] = result
         return result
 
-    def saori_unload(self, saori):
+    @classmethod
+    def saori_unload(cls, saori):
         result = 0
-        if saori in self.saori_list and self.saori_list[saori][1] != 0:
-            result = self.saori_list[saori][0].unload()
-            self.saori_list[saori][1] = 0
+        if saori in cls.saori_list and cls.saori_list[saori][1] != 0:
+            result = cls.saori_list[saori][0].unload()
+            cls.saori_list[saori][1] = 0
         return result
 
-    def saori_request(self, saori, req):
+    @classmethod
+    def saori_request(cls, saori, req):
         result = 'SAORI/1.0 500 Internal Server Error'
-        if saori in self.saori_list:
-            if self.saori_list[saori][1] == 0:
+        if saori in cls.saori_list:
+            if cls.saori_list[saori][1] == 0:
                 head, tail = os.path.split(saori)
-                self.saori_list[saori][1] = \
-                                          self.saori_list[saori][0].load(head)
-            if self.saori_list[saori][1]:
-                result = self.saori_list[saori][0].request(req)
+                cls.saori_list[saori][1] = cls.saori_list[saori][0].load(head)
+            if cls.saori_list[saori][1]:
+                result = cls.saori_list[saori][0].request(req)
         return result
