@@ -3,7 +3,7 @@
 #  niseshiori.py - a "偽栞" compatible Shiori module for ninix
 #  Copyright (C) 2001, 2002 by Tamito KAJIYAMA
 #  Copyright (C) 2002, 2003 by MATSUMURA Namihiko <nie@counterghost.net>
-#  Copyright (C) 2002-2011 by Shyouzou Sugitani <shy@users.sourceforge.jp>
+#  Copyright (C) 2002-2012 by Shyouzou Sugitani <shy@users.sourceforge.jp>
 #  Copyright (C) 2003 by Shun-ichi TAHARA <jado@flowernet.gr.jp>
 #
 #  This program is free software; you can redistribute it and/or modify it
@@ -97,7 +97,7 @@ class NiseShiori(object):
                             pass
                         continue
                     elif line.startswith('# ns_tn: '):
-                        self.username = line[9:].strip()
+                        self.username = unicode(line[9:].strip(), 'utf-8', 'ignore')
                         continue
                     try:
                         name, value = [s.strip() for s in line.split('=')]
@@ -105,7 +105,7 @@ class NiseShiori(object):
                         logging.error(
                             'niseshiori.py: malformed database (ignored)')
                         return
-                    dic[name] = value
+                    dic[name] = unicode(value, 'utf-8', 'ignore')
         except IOError:
             return
         self.variables = dic
@@ -116,10 +116,14 @@ class NiseShiori(object):
         try:
             with open(self.dbpath, 'w') as f:
                 f.write('# ns_st: {0:d}\n'.format(self.ai_talk_interval))
-                f.write('# ns_tn: {0}\n'.format(self.username))
+                f.write('# ns_tn: {0}\n'.format(
+                        self.username.encode('utf-8', 'ignore')))
+                print 'NS:', self.variables.keys()
                 for name, value in self.variables.items():
                     if not name.startswith('_'):
-                        f.write('{0}={1}\n'.format(name, str(value)))
+                        f.write('{0}={1}\n'.format(
+                                name,
+                                unicode(value).encode('utf-8')))
         except IOError:
             logging.error('niseshiori.py: cannot write database (ignored)')
             return
@@ -331,7 +335,8 @@ class NiseShiori(object):
 
     def syntax_error(self, path, line):
         logging.debug(
-            'niseshiori.py: syntax error in {0}'.format(os.path.basename(path)))
+            'niseshiori.py: syntax error in {0}'.format(
+                os.path.basename(path)))
         logging.debug(line)
 
     re_comp_op = re.compile('<[>=]?|>=?|=')
@@ -377,44 +382,14 @@ class NiseShiori(object):
                             ((y & 0x0c) << 2) | ((x & 0x0c) << 4)))
         return buf
 
-    # SHIORI/1.0 API
     def getaistringrandom(self):
         result = self.get_event_response('OnNSRandomTalk') or self.get(r'\e')
-        return result.encode('utf-8', 'ignore')
-
-    def getaistringfromtargetword(self, word):
-        word = unicode(word, 'utf-8', 'ignore')
-        return self.get(r'\e').encode('utf-8', 'ignore') # XXX
-
-    def getdms(self):
-        return self.get(r'\dms').encode('utf-8', 'ignore')
-
-    def getword(self, word_type):
-        return self.get(''.join(('\\', word_type))).encode('utf-8', 'ignore')
-
-    # SHIORI/2.4 API
-    def teach(self, word):
-        return None
-
-    # SHIORI/2.5 API
-    def getstring(self, name):
-        name = unicode(name, 'utf-8', 'ignore')
-        result = self.resources.get(name)
-        if result is not None:
-            result = result.encode('utf-8', 'ignore')
         return result
 
-    # SHIORI/2.2 API
     def get_event_response(self, event,
                            ref0=None, ref1=None, ref2=None, ref3=None,
                            ref4=None, ref5=None, ref6=None, ref7=None):
-        def proc(ref):
-            if ref is not None and \
-               not isinstance(ref, int) and not isinstance(ref, float):
-                ref = unicode(ref, 'utf-8', 'ignore')
-            return ref
-        ref = [proc(ref) for ref in [ref0, ref1, ref2, ref3, ref4,
-                                     ref5, ref6, ref7]]
+        ref = [ref0, ref1, ref2, ref3, ref4, ref5, ref6, ref7]
         if event in ['OnSecondChange', 'OnMinuteChange']:
             if ref[1]:
                 self.mikire += 1
@@ -455,9 +430,9 @@ class NiseShiori(object):
                                         break
                                     value = self.eval_ns_tag(match.group())
                                     s = ''.join((s[:match.start()],
-                                                 str(value),
+                                                 unicode(value),
                                                  s[match.end():]))
-                            return s.encode('utf-8', 'ignore')
+                            return s
                     return self.getaistringrandom()
             return None
         elif event == 'OnMouseMove':
@@ -501,10 +476,10 @@ class NiseShiori(object):
                         break
                     value = self.eval_ns_tag(match.group())
                     script = ''.join((script[:match.start()],
-                                      str(value),
+                                      unicode(value),
                                       script[match.end():]))
             self.sender = ''
-            return script.encode('utf-8', 'ignore')
+            return script
         key = 'action'
         self.dict[key] = []
         self.event = event
@@ -519,7 +494,7 @@ class NiseShiori(object):
         self.event = None
         self.reference = None
         if script is not None:
-            script = script.encode('utf-8', 'ignore')
+            script = script
         return script
 
     def otherghostname(self, ghost_list):
@@ -532,7 +507,7 @@ class NiseShiori(object):
     def communicate_to(self):
         to = self.to
         self.to = ''
-        return to.encode('utf-8', 'ignore')
+        return to
 
     def eval_condition(self, condition):
         for cond_type, expr in condition:
@@ -548,8 +523,8 @@ class NiseShiori(object):
                 op1 = int(value1)
                 op2 = int(value2)
             except ValueError:
-                op1 = str(value1)
-                op2 = str(value2)
+                op1 = unicode(value1)
+                op2 = unicode(value2)
             if expr[1] == '>=':
                 return op1 >= op2
             elif expr[1] == '<=':
@@ -566,7 +541,7 @@ class NiseShiori(object):
             if expr in self.event:
                 return 1
             for ref in self.reference:
-                if ref is not None and expr in str(ref):
+                if ref is not None and expr in unicode(ref):
                     return 1
             return 0
         else:
@@ -583,7 +558,7 @@ class NiseShiori(object):
                 if not match:
                     break
                 value = self.eval_ns_tag(match.group())
-                s = ''.join((s[:match.start()], str(value), s[match.end():]))
+                s = ''.join((s[:match.start()], unicode(value), s[match.end():]))
         return s
 
     def eval_ns_tag(self, tag):
@@ -630,7 +605,9 @@ class NiseShiori(object):
                     self.variables[name] = value
                     if not name.startswith('_'):
                         self.save_database()
-                    logging.debug('set {0} = "{1}"'.format(name, value))
+                    logging.debug('set {0} = "{1}"'.format(
+                            name,
+                            value.encode('utf-8', 'ignore')))
                 else:
                     logging.debug('niseshiori.py: syntax error')
                     logging.debug(tag)
@@ -671,7 +648,9 @@ class NiseShiori(object):
                                 candidates_B.remove(word)
                             if not candidates_A and not candidates_B:
                                 del chains[chained_meta]
-                            logging.debug('chained: {0} => {1}'.format(meta, word))
+                            logging.debug('chained: {0} => {1}'.format(
+                                    meta,
+                                    word.encode('utf-8', 'ignore')))
                             break
                     else:
                         if match.group(4) == 'm?':
@@ -687,16 +666,22 @@ class NiseShiori(object):
                     prefix = 'chain:'
                     for k, (candidates_A, candidates_B) in chains.items():
                         for w in candidates_A:
-                            logging.debug('{0} {1}, {2}'.format(prefix, k, w))
+                            logging.debug('{0} {1}, {2}'.format(
+                                    prefix,
+                                    k.encode('utf-8', 'ignore'),
+                                    w.encode('utf-8', 'ignore')))
                             prefix = '      '
                         for w in candidates_B:
-                            logging.debug('{0} {1}, {2}'.format(prefix, k, w))
+                            logging.debug('{0} {1}, {2}'.format(
+                                    prefix,
+                                    k.encode('utf-8', 'ignore'),
+                                    w.encode('utf-8', 'ignore')))
                             prefix = '      '
                     variables[meta] = word
                     variable_chains.append(chains)
                 buf.append(variables[meta])
             else:
-                buf.append(str(self.expand_meta(meta)))
+                buf.append(unicode(self.expand_meta(meta)))
             pos = match.end()
         t = ''.join(buf)
         return t
@@ -705,7 +690,8 @@ class NiseShiori(object):
         choices = []
         for keyword, word in self.type_chains.get(key, []):
             if keyword in context:
-                logging.debug('chain keyword: {0}'.format(keyword))
+                logging.debug('chain keyword: {0}'.format(
+                        keyword.encode('utf-8', 'ignore')))
                 choices.append(word)
         if not choices:
             match = self.re_category.match(key)
@@ -714,13 +700,14 @@ class NiseShiori(object):
             choices = self.dict.get(key)
         if not choices:
             if isinstance(key, tuple):
-                key = '({0}, {1})'.format(*key)
-            logging.debug('{0} not found'.format(key))
+                key = u'({0}, {1})'.format(*key)
+            logging.debug('{0} not found'.format(
+                    key.encode('utf-8', 'ignore')))
             return default
         s = random.choice(choices)
         t = self.replace_meta(s)
         if isinstance(key, tuple):
-            key = '\\{0}[{1}]'.format(key[0] or '', key[1])
+            key = u'\\{0}[{1}]'.format(key[0] or '', key[1])
         logging.debug(
             ''.join((key.encode('utf-8', 'ignore'), '=>',
                      s.encode('utf-8', 'ignore'))))
@@ -802,9 +789,9 @@ class NiseShiori(object):
             result = str(self.kasanari)
         elif name == '%ver': ## FIXME
             if REVISION[1:11] == 'Revision: ':
-                result = '偽栞 for ninix (rev.{0})'.format(REVISION[11:-2])
+                result = u'偽栞 for ninix (rev.{0})'.format(REVISION[11:-2])
             else:
-                result = '偽栞 for ninix'
+                result = u'偽栞 for ninix'
         elif name == '%sender':
             result = self.sender if self.sender else ''
         elif name == '%ghost':
@@ -832,7 +819,7 @@ class NiseShiori(object):
                 elif tree[i] == '-':
                     value = int(value) - int(operand)
             except ValueError:
-                value = ''.join((str(value), tree[i], str(operand)))
+                value = ''.join((value, tree[i], operand))
         return value
 
     def __interp_mul_expr(self, tree):
@@ -847,7 +834,7 @@ class NiseShiori(object):
                 elif tree[i] == '\\':
                     value = int(value) % int(operand)
             except (ValueError, ZeroDivisionError):
-                value = ''.join((str(value), tree[i], str(operand)))
+                value = ''.join((value, tree[i], operand))
         return value
 
     def __interp_unary_expr(self, tree):
@@ -858,7 +845,7 @@ class NiseShiori(object):
             elif tree[0] == '-':
                 return - int(operand)
         except ValueError:
-            return ''.join((tree[0], str(operand)))
+            return ''.join((tree[0], operand))
 
     def __interp_primary_expr(self, tree):
         if self.is_number(tree[0]):
@@ -1043,7 +1030,7 @@ class Shiori(NiseShiori):
             'Shiori: NiseShiori compatible module for ninix\n'
             '        Copyright (C) 2001, 2002 by Tamito KAJIYAMA\n'
             '        Copyright (C) 2002, 2003 by MATSUMURA Namihiko\n'
-            '        Copyright (C) 2002-2011 by Shyouzou Sugitani\n'
+            '        Copyright (C) 2002-2012 by Shyouzou Sugitani\n'
             '        Copyright (C) 2003 by Shun-ichi TAHARA')
 
     def request(self, req_string):
@@ -1057,7 +1044,7 @@ class Shiori(NiseShiori):
                 command = req_list[0].strip()
                 protocol = req_list[1].strip()
             for line in header:
-                line = line.strip()
+                line = unicode(line, 'utf-8', 'ignore').strip() ## FIXME
                 if not line:
                     continue
                 if ':' not in line:
@@ -1066,21 +1053,22 @@ class Shiori(NiseShiori):
                 try:
                     value = int(value)
                 except:
-                    value = str(value)
+                    pass
                 req_header[key] = value
         result = ''
         to = None
         if 'ID' in req_header:
             if req_header['ID'] == 'dms':
-                result = self.getdms()
+                result = self.get(r'\dms')
             elif req_header['ID'] == 'OnAITalk':
                 result = self.getaistringrandom()
             elif req_header['ID'] in ['\\ms', '\\mz', '\\ml', '\\mc', '\\mh',
                                       '\\mt', '\\me', '\\mp']:
-                result = self.getword(req_header['ID'][1:])
+                result = self.get(req_header['ID'])
             elif req_header['ID'] == '\\m?':
-                result = self.getword(random.choice(['ms', 'mz', 'ml', 'mc',
-                                                     'mh', 'mt', 'me', 'mp']))
+                result = self.get(random.choice(['\\ms', '\\mz', '\\ml',
+                                                 '\\mc', '\\mh', '\\mt',
+                                                 '\\me', '\\mp']))
             elif req_header['ID'] == 'otherghostname':
                 otherghost = []
                 for n in range(128):
@@ -1090,9 +1078,10 @@ class Shiori(NiseShiori):
                 result = self.otherghostname(otherghost)
             elif req_header['ID'] == 'OnTeach':
                 if 'Reference0' in req_header:
-                    self.teach(req_header['Reference0'])
+                    #self.teach(req_header['Reference0'])
+                    pass ## FIXME
             else:
-                result = self.getstring(req_header['ID'])
+                result = self.resources.get(req_header['ID'])
                 if result is None:
                     ref = []
                     for n in range(8):
@@ -1111,9 +1100,10 @@ class Shiori(NiseShiori):
         result = 'SHIORI/3.0 200 OK\r\n' \
                  'Sender: Niseshiori\r\n' \
                  'Charset: UTF-8\r\n' \
-                 'Value: {0}\r\n'.format(result)
+                 'Value: {0}\r\n'.format(result.encode('utf-8', 'ignore'))
         if to is not None:
-            result = ''.join((result, 'Reference0: {0}\r\n'.format(to)))
+            result = ''.join((result, 'Reference0: {0}\r\n'.format(
+                        to.encode('utf-8', 'ignore'))))
         result = ''.join((result, '\r\n'))
         return result
 
@@ -1131,7 +1121,9 @@ def test():
     if not list_dict(top_dir):
         print 'no dictionary'
         return
-    ns = ns_open(top_dir, 4 + 8 + 16)
+    logger = logging.getLogger()
+    logger.setLevel(logging.DEBUG) # XXX
+    ns = ns_open(top_dir)
     dump_dict(ns)
     while 1:
         print ns.getaistringrandom()
@@ -1144,7 +1136,7 @@ def dump_dict(ns):
     print 'DICT'
     for k, v in ns.dict.items():
         if isinstance(k, tuple):
-            k = '({0}, {1})'.format(*k)
+            k = u'({0}, {1})'.format(*k)
         print k.encode('utf-8', 'ignore')
         for e in v: print '\t', e.encode('utf-8', 'ignore')
     print '*' * 50
@@ -1152,13 +1144,13 @@ def dump_dict(ns):
     for t, chain_list in ns.type_chains.items():
         print t.encode('utf-8', 'ignore')
         for c, w in chain_list:
-            print ('-> {0}, {1}'.format(c, w)).encode('utf-8', 'ignore')
+            print (u'-> {0}, {1}'.format(c, w)).encode('utf-8', 'ignore')
     for key, dic in ns.word_chains.items():
-        print ('({0}, {1})'.format(*key)).encode('utf-8', 'ignore')
+        print (u'({0}, {1})'.format(*key)).encode('utf-8', 'ignore')
         for t, chain_list in dic.items():
-            prefix = '-> {0}'.format(t.encode('utf-8', 'ignore'))
+            prefix = u'-> {0}'.format(t.encode('utf-8', 'ignore'))
             for c, w in chain_list:
-                print prefix, ('-> {0}, {1}'.format(c, w)).encode('utf-8', 'ignore')
+                print prefix, (u'-> {0}, {1}'.format(c, w)).encode('utf-8', 'ignore')
                 prefix = ''.join(('   ', ' ' * len(t)))
     print '*' * 50
     print 'KEYWORDS'
@@ -1186,7 +1178,7 @@ def print_condition(condition):
     prefix = 'Condition'
     for cond_type, expr in condition:
         if cond_type == NiseShiori.COND_COMPARISON:
-            print prefix, ("'{0}' '{1}' '{2}'".format(*expr)).encode('utf-8', 'ignore')
+            print prefix, (u"'{0}' '{1}' '{2}'".format(*expr)).encode('utf-8', 'ignore')
         elif cond_type == NiseShiori.COND_STRING:
             print prefix, "'{0}'".format(expr.encode('utf-8', 'ignore'))
         prefix = '      and'
