@@ -3,7 +3,7 @@
 #  satori.py - a "里々" compatible Shiori module for ninix
 #  Copyright (C) 2002 by Tamito KAJIYAMA
 #  Copyright (C) 2002, 2003 by MATSUMURA Namihiko <nie@counterghost.net>
-#  Copyright (C) 2002-2011 by Shyouzou Sugitani <shy@users.sourceforge.jp>
+#  Copyright (C) 2002-2012 by Shyouzou Sugitani <shy@users.sourceforge.jp>
 #  Copyright (C) 2003, 2004 by Shun-ichi TAHARA <jado@flowernet.gr.jp>
 #
 #  This program is free software; you can redistribute it and/or modify it
@@ -334,7 +334,7 @@ class Parser(object):
             talk_list.append(buf)
             if self.is_anchor:
                 self.anchor_list.append(
-                    [name, '\\_a[{0}]{0}\\_a'.format(name)])
+                    [name, u'\\_a[{0}]{0}\\_a'.format(name)])
 
     def parse_word_group(self, linelist, phi_escape):
         lineno = linelist[0]
@@ -747,7 +747,8 @@ class Parser(object):
         for node in node_list:
             indent = '  ' * depth
             if node[0] == NODE_TEXT:
-                print ''.join((indent, 'NODE_TEXT "{0}"'.format(''.join(node[1]))))
+                print ''.join((indent, 'NODE_TEXT "{0}"'.format(''.join(
+                                [x.encode('utf-8') for x in node[1]]))))
             elif node[0] == NODE_REF:
                 print ''.join((indent, 'NODE_REF'))
                 self.print_nodelist(node[1], depth + 1)
@@ -1358,7 +1359,7 @@ class Satori(object):
             self.current_reset_surface = [0, 0]
         script = self.get(name, default=None)
         if script is not None and script and script != '\\n':
-            ##logging.debug('make("{0}")'.format(script))
+            ##logging.debug('make("{0}")'.format(script.encode('utf-8')))
             return self.make(''.join((head, script, tail)))
         return None
 
@@ -1498,7 +1499,7 @@ class Satori(object):
                     start = match.start()
                     if start < len(self.newline) or \
                        script[start - len(self.newline):start] != self.newline:
-                       script = r'{0}{1}{2}'.format(
+                       script = ur'{0}{1}{2}'.format(
                            script[:match.end()], self.newline_script,
                            script[match.end():])
                 else:
@@ -1516,7 +1517,7 @@ class Satori(object):
                     start = match.start()
                     if start < len(self.newline) or \
                        script[start - len(self.newline):start] != self.newline:
-                       script = r'{0}{1}{2}'.format(
+                       script = ur'{0}{1}{2}'.format(
                            script[:match.end()], self.newline_script,
                            script[match.end():])
                 else:
@@ -1672,7 +1673,7 @@ class Satori(object):
                     id_ = label
                 else:
                     id_ = self.expand(node[2])
-                buf.append(r'\q[{0},{1}]\n'.format(label, id_))
+                buf.append(ur'\q[{0},{1}]\n'.format(label, id_))
                 talk = 1
             elif node[0] == NODE_OR_EXPR:
                 for i in range(1, len(node)):
@@ -1883,7 +1884,7 @@ class Satori(object):
                     return self.to_zenkaku(1)
                 else:
                     return self.to_zenkaku(0)
-        return '（{0}）'.format(key)
+        return u'（{0}）'.format(key)
 
     def calc_args(self, args, history, expand_only=0):
         buf = []
@@ -2250,7 +2251,7 @@ class Shiori(Satori):
             'Shiori: SATORI compatible module for ninix\n'
             '        Copyright (C) 2002 by Tamito KAJIYAMA\n'
             '        Copyright (C) 2002, 2003 by MATSUMURA Namihiko\n'
-            '        Copyright (C) 2002-2011 by Shyouzou Sugitani\n'
+            '        Copyright (C) 2002-2012 by Shyouzou Sugitani\n'
             '        Copyright (C) 2003, 2004 by Shun-ichi TAHARA')
 
     def request(self, req_string):
@@ -2321,9 +2322,9 @@ class Shiori(Satori):
         result = 'SHIORI/3.0 200 OK\r\n' \
                  'Sender: Satori\r\n' \
                  'Charset: EUC-JP\r\n' \
-                 'Value: {0}\r\n'.format(result)
+                 u'Value: {0}\r\n'.format(result)
         if to is not None:
-            result = ''.join((result, 'Reference0: {0}\r\n'.format(to)))
+            result = ''.join((result, u'Reference0: {0}\r\n'.format(to)))
         result = ''.join((result, '\r\n'))
         return result.encode('EUC-JP') ## FIXME
 
@@ -2342,12 +2343,12 @@ class Shiori(Satori):
         default_args = self.saori_function[name][1:]
         n = len(default_args)
         for i in range(len(default_args)):
-              req = ''.join((req, 'Argument{0}: {1}\r\n'.format(i, default_args[i])))
+              req = ''.join((req, u'Argument{0}: {1}\r\n'.format(i, default_args[i])))
         for i in range(len(args)):
               argument = args[i]
               if argument:
                   req = ''.join((req,
-                                 'Argument{0}: {1}\r\n'.format(i + n, argument)))
+                                 u'Argument{0}: {1}\r\n'.format(i + n, argument)))
         req = ''.join((req, '\r\n'))
         response = self.saori_library.request(
             self.saori_function[name][0],
@@ -2421,6 +2422,8 @@ def satori_open(top_dir):
 ###   TEST   ###
 
 def test():
+    logger = logging.getLogger()
+    logger.setLevel(logging.DEBUG) # XXX
     if sys.argv[1] == 'ini':
         test_ini(sys.argv[2])
     elif sys.argv[1] == 'parser':
@@ -2465,7 +2468,7 @@ def test_interp(top_dir):
     satori.load()
     while 1:
         try:
-            name = raw_input(u'>>> ')
+            name = unicode(raw_input(u'>>> '), 'utf-8', 'ignore') ## FIXME
         except:
             break
         if name.startswith(u'＠'):
@@ -2474,6 +2477,7 @@ def test_interp(top_dir):
             print satori.get_event_response(name[2:])
         else:
             print satori.get_event_response(name)
+        print satori.get_script(name)
 
 if __name__ == '__main__':
     test()
