@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-#  Copyright (C) 2004-2011 by Shyouzou Sugitani <shy@users.sourceforge.jp>
+#  Copyright (C) 2004-2012 by Shyouzou Sugitani <shy@users.sourceforge.jp>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -398,8 +398,9 @@ class Skin(object):
         if self.id[1] is not None:
             self.id[1] += 1
         else:
-            if not random.choice(range(100)): ## XXX
-                self.id[1] = 0
+            if random.choice(range(100)): ## XXX
+                return
+            self.id[1] = 0
         self.set_surface()
 
     def start(self): ## FIXME
