@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 #  Copyright (C) 2001-2004 by MATSUMURA Namihiko <nie@counterghost.net>
-#  Copyright (C) 2004-2011 by Shyouzou Sugitani <shy@users.sourceforge.jp>
+#  Copyright (C) 2004-2012 by Shyouzou Sugitani <shy@users.sourceforge.jp>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -705,7 +705,10 @@ class NGM(object):
                 for element in ['Name', 'SakuraName', 'KeroName',
                                 'Author', 'HPTitle']:
                     text = self.catalog.get(entry, element)
-                    if text and word in text:
+                    if not text:
+                        continue
+                    text = unicode(text, 'utf-8')
+                    if word in text:
                         self.current = set_id
                         return True
             set_id += 1
