@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-#  Copyright (C) 2003-2011 by Shyouzou Sugitani <shy@users.sourceforge.jp>
+#  Copyright (C) 2003-2012 by Shyouzou Sugitani <shy@users.sourceforge.jp>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -292,13 +292,9 @@ def create_pixbuf_from_file(path, is_pnr=True, use_pna=False):
             r, g, b = array[0][0]
             pixbuf = pixbuf.add_alpha(True, chr(r), chr(g), chr(b))
         else:
-            ar = numpy.frombuffer(array, numpy.uint8)
-            alen = pixbuf.get_width() * pixbuf.get_height()
-            ar.shape = alen, 4
+            ar = numpy.frombuffer(array, numpy.uint32)
             rgba = ar[0]
-            index = numpy.ravel(ar == rgba)
-            index.shape = alen, 4
-            ar[numpy.all(index, 1)] = 0
+            ar[ar == rgba] = 0x00000000
     if use_pna:
         path = os.path.join(head, ''.join((basename, '.pna')))
         if os.path.exists(path):
