@@ -2,7 +2,7 @@
 #
 #  Copyright (C) 2001, 2002 by Tamito KAJIYAMA
 #  Copyright (C) 2002, 2003 by MATSUMURA Namihiko <nie@counterghost.net>
-#  Copyright (C) 2002-2011 by Shyouzou Sugitani <shy@users.sourceforge.jp>
+#  Copyright (C) 2002-2012 by Shyouzou Sugitani <shy@users.sourceforge.jp>
 #  Copyright (C) 2003-2005 by Shun-ichi TAHARA <jado@flowernet.gr.jp>
 #
 #  This program is free software; you can redistribute it and/or modify it
@@ -291,12 +291,77 @@ class SSTPControler(object):
             logging.info('Serving SSTP on port {0:d}'.format(port))
 
 
+class PluginDialog:
+
+    def __init__(self, plugin_dir, queue, message):
+        self.plugin_dir = plugin_dir
+        self.queue = queue
+        dialog = gtk.Window()
+        dialog.set_title(plugin_dir)
+        ##dialog.set_decorated(False)
+        ##dialog.set_resizable(False)
+        dialog.connect('delete_event', self.delete)
+        dialog.connect('key_press_event', self.key_press)
+        dialog.connect('button_press_event', self.button_press)
+        dialog.set_events(gtk.gdk.BUTTON_PRESS_MASK)
+        ##dialog.set_modal(True)
+        dialog.set_position(gtk.WIN_POS_CENTER)
+        dialog.realize()
+        entry = gtk.Entry()
+        entry.connect('activate', self.activate)
+        entry.set_size_request(320, -1)
+        entry.show()
+        box = gtk.VBox(spacing=10)
+        box.set_border_width(10)
+        label = gtk.Label(message)
+        box.pack_start(label, False)
+        label.show()
+        box.pack_start(entry)
+        dialog.add(box)
+        box.show()
+        self.dialog = dialog
+
+    def open(self):
+        self.dialog.show()
+
+    def delete(self, widget, event):
+        self.dialog.hide()
+        self.cancel()
+        return True
+
+    def key_press(self, widget, event):
+        if event.keyval == gtk.keysyms.Escape:
+            self.dialog.hide()
+            self.cancel()
+            return True
+        return False
+
+    def button_press(self, widget, event):
+        if event.button in [1, 2]:
+            self.dialog.begin_move_drag(
+                event.button, int(event.x_root), int(event.y_root),
+                gtk.get_current_event_time())
+        return True
+
+    def activate(self, widget):
+        self.dialog.hide()
+        self.enter(widget.get_text())
+        return True
+
+    def enter(self, text): 
+        self.queue.put(text)
+
+    def cancel(self):
+        self.queue.put('')
+
+
 class PluginControler:
 
     def __init__(self):
         self.jobs = {}
         self.queue = {}
         self.data = {}
+        self.dialog = {}
         self.request_parent = lambda *a: None # dummy
         
     def set_responsible(self, request_method):
@@ -351,20 +416,30 @@ class PluginControler:
             self.save_data(plugin_dir)
         return ## FIXME
 
+    def open_dialog(self, plugin_dir, message):
+        self.dialog[plugin_dir] = PluginDialog(plugin_dir,
+                                               self.queue[plugin_dir],
+                                               message)
+        self.dialog[plugin_dir].open()
+
     def check_queue(self):
         for plugin_dir in self.jobs.keys():
             if not self.queue[plugin_dir].empty():
                 data = self.queue[plugin_dir].get()
                 self.queue[plugin_dir].task_done()
-                if not isinstance(data, dict):
+                if isinstance(data, basestring):
+                    if data.startswith('DIALOG:'):
+                        message = data[7:]
+                        self.open_dialog(plugin_dir, message)
+                        continue
+                elif not isinstance(data, dict):
                     continue
                 for name, value in data.items():
                     if not isinstance(name, basestring) or ':' in name or \
                             not (isinstance(value, basestring) or value is None):
                         break
                 else:
-                    if plugin_dir not in self.data:
-                        self.data[plugin_dir] = {}
+                    assert plugin_dir in self.data
                     self.data[plugin_dir].update(data)
 
     def exec_plugin(self, plugin_dir, argv, caller):
@@ -379,10 +454,9 @@ class PluginControler:
             return
         port = self.request_parent('GET', 'get_sstp_port')
         queue = multiprocessing.JoinableQueue()
-        if plugin_dir in self.data:
-            data = self.data[plugin_dir]
-        else:
-            data = self.load_data(plugin_dir)
+        if plugin_dir not in self.data:
+            self.data[plugin_dir] = self.load_data(plugin_dir)
+        data = self.data[plugin_dir]
         p = module.Plugin(port, target_dir, argv[1:], home_dir, caller,
                           queue, data)
         if not isinstance(p, ninix.plugin.BasePlugin):
@@ -828,7 +902,7 @@ class Application(object):
             return 0
 
     def update_sakura(self, name, sender):
-        key = self.find_ghost_by_name(name, '')
+        key = self.find_ghost_by_name(name)
         if key is None:
             return
         sakura = self.ghosts[key].instance
@@ -906,7 +980,7 @@ class Application(object):
         self.change_sakura(sakura, key, 'automatic', event, vanished)
 
     def select_ghost_by_name(self, sakura, name, event=1):
-        key = self.find_ghost_by_name(name, 0)
+        key = self.find_ghost_by_name(name)
         if key is None:
             return
         self.change_sakura(sakura, key, 'automatic', event)
